[![DOI](https://zenodo.org/badge/297107471.svg)](https://zenodo.org/badge/latestdoi/297107471)

# Quickstart
Module to extract the envelope of signals.

Interactive visualizations [here](https://envelope.netlify.app/).

An exe for Win64 machines can be found in the releases section. For usage info run the exe with the -h flag.
A Python module implementing the same functionality can be found [here](https://pypi.org/project/signal-envelope/).
A number of test wav files can be found at the /test_samples folder.


# Documentation

## [C++](https://tesserato.github.io/envelope/html/index.html)

## [Python](https://pypi.org/project/signal-envelope/)


# Used Libraries

[Libsndfile](http://www.mega-nerd.com/libsndfile/)
[Boost](https://www.boost.org/)
[Intel Math Kernel Library](https://software.intel.com/content/www/us/en/develop/tools/oneapi/components/onemkl.html#gs.9syxj0)